import unittest
import os

from katello.tests.core.action_test_utils import CLIOptionTestCase, CLIActionTestCase
from katello.tests.core.organization import organization_data
from katello.tests.core.template import template_data

import katello.client.core.template
from katello.client.core.template import Update
from katello.client.api.utils import ApiDataError


class RequiredCLIOptionsTests(CLIOptionTestCase):
    #requires: organization, name
    #optional: NONE

    action = Update()

    disallowed_options = [
        ('--name=template_1', ),
        ('--org=ACME', ),
    ]

    allowed_options = [
        ('--org=ACME', '--name=template_1'),
    ]


class TemplateUpdateTest(CLIActionTestCase):

    ORG = organization_data.ORGS[0]
    ENV = organization_data.LIBRARY
    TPL = template_data.TEMPLATES[0]

    TPL_DESC = "description of the template"
    TPL_PARENT_NAME = 'parent_template'
    TPL_PARENT_ID = 83

    OPTIONS = {
        'org':  ORG['name'],
        'name': TPL['name']
    }

    OPTIONS_WITH_PARENT = {
        'org': ORG['name'],
        'name': TPL['name'],
        'parent': TPL_PARENT_NAME
    }

    def setUp(self):
        self.set_action(Update())
        self.set_module(katello.client.core.template)
        self.mock_printer()

        self.mock_options(self.OPTIONS)

        self.mock(self.action.api, 'templates', template_data.TEMPLATES)

        self.mock(self.module, 'get_environment', self.ENV)
        self.mock(self.module, 'get_library', self.ENV)
        self.mock(self.module, 'get_template', self.TPL)

        self.mock(self.action, 'updateTemplate')
        self.mock(self.action, 'updateContent')

        self.mock_spinner()


    def test_it_finds_the_template_by_name(self):
        self.mock_options(self.OPTIONS)
        self.run_action()
        self.module.get_template.assert_called_with(self.ORG['name'], self.ENV['name'], self.TPL['name'])

    def test_it_returns_error_when_template_not_found(self):
        self.mock(self.module, 'get_template').side_effect = ApiDataError
        self.run_action(os.EX_DATAERR)

    def test_it_finds_parent_template(self):
        self.mock_options(self.OPTIONS_WITH_PARENT)
        self.mock(self.action, 'get_parent_id', self.TPL_PARENT_ID)
        self.run_action()
        self.action.get_parent_id.assert_called_once_with(self.ORG['name'], self.ENV["name"], self.TPL_PARENT_NAME)

    def test_it_returns_error_when_parent_not_found(self):
        self.mock(self.module, 'get_template').side_effect = ApiDataError
        self.run_action(os.EX_DATAERR)

    def test_it_calls_update_template(self):
        self.mock_options(self.OPTIONS)
        self.run_action()
        self.action.updateTemplate.assert_called_once()

    def test_it_calls_update_content(self):
        self.mock_options(self.OPTIONS)
        self.run_action()
        self.action.updateContent.assert_called_once()

    def test_it_returns_status_ok(self):
        self.mock_options(self.OPTIONS)
        self.run_action(os.EX_OK)
